# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from hotfn.http import response


# TODO(denismakogon): add HTTP version, headers, etc.
class DispatchException(Exception):

    def __init__(self, status, message):
        """

        :param status: HTTP status code
        :param message: error message
        """
        self.status = status
        self.message = message

    def response(self):
        return response.RawResponse(
            (1, 1), self.status, 'ERROR', {}, self.message)
